summaryrefslogtreecommitdiffstats
path: root/content/renderer/render_view.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/renderer/render_view.h')
-rw-r--r--content/renderer/render_view.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/content/renderer/render_view.h b/content/renderer/render_view.h
index 444d8555..0ef0805 100644
--- a/content/renderer/render_view.h
+++ b/content/renderer/render_view.h
@@ -201,7 +201,8 @@ class RenderView : public RenderWidget,
WebKit::WebView* webview() const;
// Called by a GraphicsContext associated with this view when swapbuffers
- // completes or is aborted.
+ // is posted, completes or is aborted.
+ void OnViewContextSwapBuffersPosted();
void OnViewContextSwapBuffersComplete();
void OnViewContextSwapBuffersAborted();